@@ -1,7 +1,7 @@
 package Sah::Schema::Rinci;
 
-our $DATE = '2015-03-28'; # DATE
-our $VERSION = '1.1.75'; # VERSION
+our $DATE = '2015-04-30'; # DATE
+our $VERSION = '1.1.76'; # VERSION
 
 use 5.010001;
 use strict;
@@ -96,13 +96,7 @@ $SCHEMAS{rinci_function} = [hash => {
             },
         },
         args_as => {},
-        args_groups => {
-            _elem_prop => {
-                %dh_props,
-                args => {},
-                rel => {},
-            },
-        },
+        args_schema => {},
         result => {
             _prop => {
                 %dh_props,
@@ -206,7 +200,7 @@ Sah::Schema::Rinci - Sah schemas for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 1.1.75 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2015-03-28.
+This document describes version 1.1.76 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2015-04-30.
 
 =head1 HOMEPAGE
 
